### A Pluto.jl notebook ###
# v0.19.27

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ 3eeeedf8-d228-4178-bfc5-710f46649c2a
begin
	using PlotlyBase, HypertextLiteral, PlutoUI, PlutoTeachingTools
	using CSV, DataFrames, Dates, PeriodicalDates, StatsBase
	using NLsolve
end

# ╔═╡ 1f1076c3-5aca-4037-8d45-6a23872ceda4
function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
       # Remove responsive flag on the plot as we handle responsivity via ResizeObeserver and leaving it on makes the div flickr during updates
	hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
	show(io,mimetype, @htl("""
			<div>
			<script id=asdf>
			const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
			const PLOT = this ?? document.createElement("div");
		

		
			Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


		
			const pluto_output = currentScript.parentElement.closest('pluto-output')

			const resizeObserver = new ResizeObserver(entries => {
				Plotly.Plots.resize(PLOT)
			})

			resizeObserver.observe(pluto_output)

			invalidation.then(() => {
				resizeObserver.disconnect()
			})
		
			return PLOT
			</script>
			</div>
	"""))
end;

# ╔═╡ 680433b3-98f7-437c-9026-9533c9b4f61e
html"""
<picture>
  <source srcset="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/negative/rgb_ibs_en_horizontal_negative.png" media="(prefers-color-scheme: dark)" width="240px!important" style="float:right;">
  <img src="https://gci.iscte-iul.pt/2022/identidade/files/brand_v2/escolas/rgb/ibs/en/horizontal/main/rgb_ibs_en_horizontal_main.png" width="240px" style="float:right;">
</picture>
<title>Macroeconomics</title>
<subtitle>Sample Final test</subtitle>
<semester>Degree in Management<br>First semester 2022-23</semester>
<author>Vivaldo Mendes, Luís Clemente-Casinhas, Ricardo Gouveia-Mendes</author>
"""

# ╔═╡ 412ff565-a0ac-4014-97f6-e69f36db3fa7
@bind nome TextField(66, placeholder="Name")

# ╔═╡ 4ee58363-aab7-4091-9774-867dd1f1cbf6
@bind numero TextField(placeholder="Student number")

# ╔═╡ b9ff1ebd-b7e6-4574-9b19-1b83ea0df6d1
md"""
> The test consists of 40 **multiple choice** questions. In each question, select **the correct alternative**, unless you are told otherwise.
>
> Each multiple-choice question is worth **0.5 points**.
>
> **Wrong answers deduct -0.125 points**.
>
> It is expected that this model test **will only take 1 hour to complete**.
>
> ---
>
> **NOTE:** In the real test, there will be 50 questions and the solving time will be 1h30.
"""

# ╔═╡ 4ad6bdf1-3029-43e5-9b0f-cff6525ffe94
md"---"

# ╔═╡ ca0e61f0-f955-11ed-00af-1f63977dd3de
md"""
If there is a positive shock to AS (i.e., if $\rho$ decreases), this will:

**a)** cause the AS curve to shift to the right (i.e. downwards).

**b)** cause the AS curve to shift to the left (i.e. upwards).

**c)** Move along the AS curve.

**d)** Leave the AS curve completely unchanged.

**e)** None of the above.
"""


# ╔═╡ 584268fb-7d05-4ec1-aced-acdd66e7d7f4
@bind q01 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 8d6f36e2-cfd9-4d96-9f42-c862229ca8b7
md"""
---
"""

# ╔═╡ 5fd57b29-069d-4a2e-872e-bb9b9bbe1ff0
md"""
One of the phenomena that could lead to an upward shift in the Phillips Curve is:

**a)** A decrease in the price of oil.

**b)** An increase in the unemployment rate.

**c)** An increase in the natural rate of unemployment.

**d)** An increase in expected inflation.

**e)** None of the above.
"""


# ╔═╡ 5117e0b7-07f2-440e-9edf-098dc77b128f
@bind q02 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ cacf356b-2c1f-4b3d-b6e7-3ade4c846b5e
md"""
---
"""

# ╔═╡ 7f860aaa-b1bc-4ed7-a9aa-1b07e07cadc3
md"""
In the long term:

**a)** Increases in the inflation rate are associated with increases in output.

**b)** Aggregate demand is represented by a vertical curve in which inflation is equal to expected inflation.

**c)** Price adjustment is more rigid than in the short term.

**d)** The amount of output an economy can produce is determined by variables such as capital, labor, and technology.

**e)** None of the above.
"""


# ╔═╡ 4cf1f4da-e5e3-4fa8-a15c-41bdcc8d5c78
@bind q03 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ b938ab03-4579-4c79-89d2-2d2b87d8a57c
md"""
---
"""

# ╔═╡ 5265edb5-ec8b-434c-bef2-1b45dbd143b7
let
	output = 0:1:16
	PC = 3.0 .+(0.5 .* 0.5).*(output .- 10.0)
	trace7_24 = scatter(;x =output, y = PC, 
					name = "AS", line_color = "Blue", mode = "lines", 
					line_width="2.0")		
	trace7_25 = scatter(; x = [8.0, 10.0, 12.0], y = [2.5, 3.0 , 3.5], text = ["2", "1" , "3"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="blue",	
					textfont = attr(family="sans serif", size=16, color="black"))
	trace7_49 = scatter(; x = [10.0, 10.0] , y = [-2,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")	
	layout7_25 = Layout(;
					title_text = "The AS curve",
					title_x = 0.5,
        			yaxis_title = "Rate of Inflation (π)",
					yaxis_zeroline= false,
					hovermode="x",
        			xaxis_range = [6.0, 14.0],
        			xaxis_title = "GDP in trillion dollars (Y)",
					xaxis_zeroline= false,
        			yaxis_range=[2.0, 4.0], 
        			titlefont_size=18)	
	p7_25=Plot([trace7_49, trace7_24, trace7_25], layout7_25)
end

# ╔═╡ 29889baf-6d1a-45e7-8af4-ea9238715c47
md"""
Knowing that potential GDP (Yᴾ) is equal to 10 trillion dollars (as shown in the figure above), the economy moves from point 1 to 3 due to the fact that:

**a)** The economy has entered an economic boom, which has led to a reduction in the inflation rate.

**b)** The economy has entered an economic boom, which has led to an increase in the inflation rate.

**c)** The economy entered an economic recession, which led to a reduction in the inflation rate.

**d)** The economy entered an economic recession, which led to an increase in the inflation rate.

**e)** None of the above.
"""


# ╔═╡ 617482da-379f-448a-b021-8a2d0a80416e
@bind q04 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 50b2e323-a5a4-4f2f-a82f-678ef2ec0b23
md"""
---
"""

# ╔═╡ 8a796898-03c2-4b93-98d8-bb95ae46e45c
md"""
Okun's Law represents:

**a)** A positive relationship between the cyclical unemployment rate and the output-gap.

**b)** A negative relationship between the unemployment rate and potential GDP.

**c)** A positive relationship between the natural unemployment rate and GDP.

**d)** A negative relationship between the cyclical unemployment rate and the output gap.

**e)** None of the above.
"""


# ╔═╡ a8f403a7-6d38-435e-8307-22388809b267
@bind q05 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6bba8792-7341-469a-a729-4e5297c216a7
md"""
---
"""

# ╔═╡ c0147dfb-3abc-4ef3-9d3d-215cf69deb02
let
	output = 0:1:16
	PC = 3.0 .+(0.5 .* 0.5).*(output .- 10.0)
	trace7_24 = scatter(;x =output, y = PC, 
					name = "AS", line_color = "Blue", mode = "lines", 
					line_width="2.5")		
	trace7_25 = scatter(; x = [8.0, 10.0, 12.0], y = [2.5, 3.0 , 3.5], text = ["2", "1" , "3"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="blue",	
					textfont = attr(family="sans serif", size=16, color="black"))
	trace7_49 = scatter(; x = [10.0, 10.0] , y = [-2,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")	
	trace7_41 = scatter(; x = [8.0, 10.0, 12.0], y = [3.0, 3.5 , 4.0], text = ["2'", "1'" , "3'"], 
					textposition = "top center", name = "", mode="markers+text", marker_size= "12",
					marker_color="Red",	
					textfont = attr(family="sans serif", size=16, color="black"))
	layout7_25 = Layout(;
					title_text = "The AS curve",
					title_x = 0.5,
        			yaxis_title = "Rate of Inflation (π)",
					yaxis_zeroline= false,
					hovermode="x",
        			xaxis_range = [6.0, 14.0],
        			xaxis_title = "GDP in trillion dollars (Y)",
					xaxis_zeroline= false,
        			yaxis_range=[2.0, 4.2], 
        			titlefont_size=18)
	p7_25=Plot([trace7_49, trace7_24, trace7_25, trace7_41], layout7_25)
end

# ╔═╡ 5c40e68a-da32-4bd0-af8e-c3141318d0a7
md"""
In the figure above, how do you justify the shift in the AS curve from point 2 to 2'?

**a)** A positive shock to AS of $-0.5$ percentage points.

**b)** A rise in GDP by $2 trillion.

**c)** A decrease in GDP by 2 trillion dollars.

**d)** A negative shock to SSA of $+0.5$ percentage points.

**e)** None of the above.
"""


# ╔═╡ a02a491a-ec0f-4ef9-b7c5-e31194f43c8c
@bind q06 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 85f2199b-dd49-4cef-b309-2caac31b63a0
md"""
---
"""

# ╔═╡ c0109b03-2c2f-4d93-b74c-b643c986f545
md"""
One of the phenomena that could lead to a shift along the Phillips Curve is:

**a)** A decrease in the price of oil.

**b)** An increase in the cost of energy.

**c)** A fall in the unemployment rate.

**d)** An increase in expected inflation.

**e)** None of the above.
"""


# ╔═╡ 6925cd02-56f1-48c7-9b02-c3538e101f4d
@bind q07 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c4b23302-22e3-48f7-8d77-72f4b5972162
md"""
---
"""

# ╔═╡ b46aa2bf-8576-44f4-b056-59b5edd8c3dc
md"""
If there is a positive shock to the AS (i.e., if $\rho$ decreases), this will:

**a)** cause an increase in the inflation rate $(\pi)$, for any level of GDP $(Y)$.

**b)** Cause an increase in the inflation rate $(\pi)$, as well as an increase in GDP $(Y)$.

**c)** Keep the inflation rate $(\pi)$ and GDP $(Y)$ unchanged.

**d)** Causing a decrease in the inflation rate $(\pi)$, for any level of GDP $(Y)$.

**e)** None of the above.
"""


# ╔═╡ 8a0cf087-7aff-4a17-863e-ee39015ce8a8
@bind q08 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 7fa1f70b-f880-4606-baf8-f1fe9da4222d
md"""
---
"""

# ╔═╡ 9f9e760d-c7d7-420e-8ac2-cf6f26ee837b
md"""
According to the self-correcting mechanism, how does GDP return to the value of potential GDP after a negative shock to aggregate demand?

**a)** The negative shock to demand causes aggregate output to increase for each level of the inflation rate, promoting a positive output gap, which causes inflation to rise.

**b)** Expected inflation decreases, shifting the short-term aggregate supply curve downwards along the new aggregate demand curve.

**c)** Lower inflation leads to an automatic response from the central bank to increase the real interest rate, stimulating planned spending, increasing aggregate output, and narrowing the output gap.

**d)** The negative shock to demand causes aggregate output to increase for each level of the inflation rate, promoting a negative output gap, which causes inflation to fall.

**e)** None of the above.
"""


# ╔═╡ 19e73b89-d4f1-4e82-8ae7-5db98ab7e8c7
@bind q09 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e54b0fc3-152b-4d19-a5a8-4ee258c0d6bd
md"""
---
"""

# ╔═╡ 70e53de6-c41a-472e-9140-dfcdf28598c9
md"""
A permanent positive shock to aggregate supply:

**a)** Makes the economy less efficient.

**b)** Promotes increases in the inflation rate.

**c)** Decreases aggregate output in the long term.

**d)** Can be caused by the adoption of reckless regulations.

**e)** None of the above.
"""


# ╔═╡ 7a93da9a-3380-46f9-944e-83c5ed800c55
@bind q10 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e1148fc4-c023-4611-ba8c-526adf723bae
md"""
---
"""

# ╔═╡ 649703b9-c02b-4ee0-955a-e79abb826988
md"""
The bursting of the tech bubble in 2000, the terrorist attacks of 2001 and the corporate scandals of 2001 and 2002 had similar qualitative effects on the economy. Select the scenario you would expect to have happened.

**a)** Private spending will have decreased, shifting the AD curve to the right.

**b)** Aggregate output will have fallen below potential, and the self-correction mechanism will have lowered the unemployment rate until it reaches its lowest level (around 2004).

**c)** Private spending will have increased, shifting the AD curve to the left.

**d)** Aggregate output will have risen above potential, and the self-correction mechanism will have increased the unemployment rate until it reaches its highest level (around 2004).

**e)** None of the above.
"""


# ╔═╡ 06d66a09-5a55-4a00-b024-6bf84e2f77ad
@bind q11 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 7f3a2da4-2622-472a-a63e-6aa394cabdef
md"""
---
"""

# ╔═╡ ec48a6a7-1565-4075-a933-d029197c6922
md"""
![](https://vivaldomendes.org/images/Tests/oil_prices.png)
"""

# ╔═╡ 0183c27d-9e10-4511-95df-067259f0036a
md"""
Since the summer of 2022, the oil price on the international markets has been falling gradually, as shown in the figure above. This has caused:

**a)** A shift in short-term aggregate supply (AS curve) to the left (i.e., upwards).

**b)** An increase in aggregate demand (AD curve), shifting it upwards.

**c)** A shift in short-term aggregate supply (AS curve) to the right (i.e., downwards).

**d)** A decrease in aggregate demand (AD curve), shifting it downwards.

**e)** None of the above.
"""


# ╔═╡ d149e58c-7f68-4355-91eb-b4d73466188a
@bind q12 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ ed418fd6-57ff-46e9-894d-b3acf341b5bd
md"""
---
"""

# ╔═╡ 656019a7-57f2-42d8-918f-60f1996af241
md"""
When Paul Volcker took over as the new Governor of the Federal Reserve in 1979, the inflation rate was over 10%. In 1982, the unemployment rate soared to 9.7%, and inflation fell to 6.2%. Which of the following is an appropriate description of the mechanism behind Volcker's disinflation?

**a)** The AD curve probably shifted to the left due to the less restrictive monetary policy, which explains the reduction in the inflation rate between 1979 and 1982.

**b)** Due to the more restrictive monetary policy, the output gap became negative, which explains the increase in the unemployment rate between 1979 and 1982.

**c)** In 1982, it is likely that equilibrium aggregate output was higher than potential, causing the AS curve to shift to the left to eliminate it, which explains the reduction in the unemployment rate and the further decrease in inflation between 1982 and 1986.

**d)** By lowering the Federal Funds Rate, the Federal Reserve accelerated the economy and managed to cut inflation in half in 1982 at the cost of a substantial increase in the unemployment rate, causing a recession.

**e)** None of the above.
"""


# ╔═╡ 36490f8f-c8fc-40bf-b2a7-70426e0257ba
@bind q13 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ cd0ba554-a065-4fdb-a6f1-ef575c148d04
md"""
---
"""

# ╔═╡ c39dfe8b-97d2-4601-9fa8-0214aca1179a
md"""
Select the incorrect option. A positive permanent shock to aggregate supply:

**a)** Makes the economy more efficient.

**b)** Promotes decreases in the inflation rate.

**c)** Increases aggregate output in the long run.

**d)** Can be caused by the development of a technology that increases productivity.

**e)** Increases the inflation rate.
"""


# ╔═╡ cfe4750f-2af3-42f7-a527-864b56d41733
@bind q14 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 56d15a35-50a0-487c-8240-b05f5d45c7b5
md"""
---
"""

# ╔═╡ c6b0c07b-942b-4210-87dd-db00caafed1b
md"""
The price of a barrel of oil doubled between 2007 and mid-2008. To make matters worse, a financial crisis hit the US economy in August 2007. Which of the following is an appropriate description of the mechanism that would have occurred?

**a)** The financial crisis would have led to a sharp contraction in private spending, shifting the AD curve to the right.

**b)** The oil price increase would have immediately shifted the AS curve to the right.

**c)** The financial crisis would have led to a sharp increase in private spending, shifting the AD curve to the left.

**d)** Shifts in the AD and AS curves occurred in the short term, but as long as none of the shocks had an impact on potential output, unemployment would not have been affected in the long term.

**e)** None of the above.
"""


# ╔═╡ 9fbf9a0f-759a-4ee8-af34-982779e0e5ee
@bind q15 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e55b164b-0bfe-4f9a-b9af-e3ef80f3b0c8
md"""
---
"""

# ╔═╡ d733cdb8-c84a-4844-bca7-89e4a2ea83bd
md"""
The American Rescue Plan Act of 2021 is a 1.9 trillion dollar economic stimulus bill (about 10% of GDP) passed by the US Congress and signed into law by President Joe Biden on March 11, 2021. Why did the US President enact this law?

**a)** To contract aggregate demand, which had increased enormously due to Covid19.

**b)** To stimulate aggregate demand, which had plummeted due to Covid19.

**c)** To contract aggregate supply, which had increased enormously due to Covid19.

**d)** To contract inflation, which had reached extremely high levels due to Covid19.

**e)** None of the above.
"""


# ╔═╡ 7981e102-3cf1-4ae1-ae94-c1904d636641
@bind q16 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6697f482-e053-49dd-8b3c-662c27fe2acd
md"""
---
"""

# ╔═╡ b7f5557d-6384-478b-988e-926bdc96e4e7
md"""
In the long term, a negative **temporary** supply shock will have the following effect:

**a)** Inflation and GDP values equal to their initial values.

**b)** Inflation rate different from its initial value but GDP equal to its initial value.

**c)** Inflation rate equal to its initial value but GDP different from its initial value.

**d)** Inflation and GDP values are different from the initial ones.

**e)** None of the above.
"""


# ╔═╡ 3973a512-fc1a-4dbd-af86-159172e5cd3e
@bind q17 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 410f0b75-a6b7-4deb-bfd4-64a90d3b5ce2
md"""
---
"""

# ╔═╡ c4be74e5-03c3-4781-a684-765ebc529209
md"""
`ΔĀ5b = `$(@bind ΔĀ5b Slider(-1.0:0.1:1.0, default=0.0, show_value=true))
"""

# ╔═╡ 1ec91298-655c-4fa3-8c69-6fe281dec2f9
let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ;	r̄5 = 0.5 	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 			# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       				# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5           				# The AS curve y-axis' intercept
	Y5 = 9.0:0.01:11.0
	Y5_ΔĀ5 = 8.0:0.02:15.0
	r5 = 0.0:0.005:5.0
 
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
	πs5 = πs_min5 .+ γ5 .*Y5    
	πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5
	
	πd_max5_ΔĀ5 = ((Ā5 .+ ΔĀ5b) ./ (λ5 .* ϕ5)) .- r̄5 ./ λ5 # New max value of the AD function	
	πd5_ΔĀ5 = πd_max5_ΔĀ5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5_ΔĀ5) # New AD function
	
	trace9_0 = scatter(; x = [10,10] , y = [-7,10] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))
	trace9_4 = scatter(; x = Y5_ΔĀ5, y = πd5_ΔĀ5, mode="lines" , line_color = "Magenta", 
					line_width = "3", name  = "AD2")		
	layout9_5 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title="GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])
   	p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_4, trace9_3], layout9_5)

	trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")	
	trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=18, color="black"))
	layout4_3 = Layout(;
					title_text = "MP Curve",
					title_x = 0.5,
					hovermode = "x",
	                xaxis=attr(title="Real interest rate (r)", showgrid=true, zeroline=false),
	                xaxis_range = [0.5, 3.5],
					xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])	
	p4_3 = Plot([trace4_0, trace4_1], layout4_3)
	[p4_3 p9_4]
end



# ╔═╡ 183dd55f-b4f2-4645-b427-f2b56365f317
md"""
The figures above represent the initial macroeconomic equilibrium. Suppose the government decides to _increase_ public spending by +0.3 trillion dollars.  Using the slider `ΔĀ5b` and the figures, which of the values below corresponds to the new _long-term_ equilibrium?

**a)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$

**b)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**c)** $\pi=1.5\% \ \  , \ \ Y = 9.8 \ \ , \ \ r=1.5\% \ \ , \ \ i = 3\%$

**d)** $\pi=5\% \ \  , \ \ Y = 10 \ \ , \ \ r=3\% \ \ , \ \ i = 8\%$

**e)** None of the above.
"""


# ╔═╡ c707b9f9-19a9-4eae-8d97-0d2441dd8e61
@bind q18 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 93a93d10-e825-4e3f-b513-807496cebc6d
md"""
---
"""

# ╔═╡ 479988ae-429b-41d2-8385-4c692fd62ec5
md"""
`Yp_shock = `$(@bind Yp_shock Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ 3d4ba3e0-45e5-4c33-9f1c-9def0144b1cb
let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ;	r̄5 = 0.5 	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 			# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       				# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shock) + ρ5           				# The AS curve y-axis' intercept
	Y5 = 9.0:0.01:11.0
	Y5_ΔĀ5 = 8.0:0.02:15.0
	r5 = 0.0:0.005:5.0
 
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
	πs5 = πs_min5 .+ γ5 .*Y5    
	πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5
	
	trace9_0 = scatter(; x = [10+Yp_shock,10+Yp_shock], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))	
	layout9_5 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title="GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])
   	p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

	trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")	
	trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=18, color="black"))
	layout4_3 = Layout(;
					title_text = "MP Curve",
					title_x = 0.5,
					hovermode = "x",
	                xaxis=attr(title="Real interest rate (r)", showgrid=true, zeroline=false),
	                xaxis_range = [0.5, 3.5],
					xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])	
	p4_3 = Plot([trace4_0, trace4_1], layout4_3)
	[p4_3 p9_4]
end


# ╔═╡ 0ac221d2-e690-4c16-93d6-770cec789ec6
md"""
The figures above represent the initial macroeconomic equilibrium. Suppose there is a permanent shock to supply, such that potential GDP increases by +0.6 trillion dollars. Using the slider `Yp_shock` to represent this shock, which of the figures below corresponds to the new _long-run_ equilibrium?

**a)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**b)** $\pi=1\% \ \  , \ \ Y = 10.6 \ \ , \ \ r=1\% \ \ , \ \ i = 2\%$

**c)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**d)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$

**e)** None of the above.
"""


# ╔═╡ 9f263f69-8d7b-4146-ad22-f5e601855eef
@bind q19 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 1ef1803f-2961-425f-871a-944c89434779
md"""
---
"""

# ╔═╡ 3c693419-e1da-49b8-b6c2-23287a42ecc7
md"""
Assume that the economy is in a long-term equilibrium. If there is a negative shock to aggregate demand and the Central Bank wants to stabilize economic activity before the self-correction mechanism kicks in:

**a)** It will need to accept a higher inflation figure than the initial one.

**b)** The long-term equilibrium real interest rate will be the same as before the shock.

**c)** You must accept a lower inflation rate than the initial one.

**d)** The long-term equilibrium real interest rate will be different.

**e)** None of the above.
"""


# ╔═╡ 78a5cda4-f9f7-4ca7-aa05-ceb9b338c5b8
@bind q20 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 1862ea80-beef-450c-a24b-9ed120f8f7b7
md"""
---
"""

# ╔═╡ 4222da75-5ad0-4a41-bfa3-10749bcc994c
md"""
In the mid-1990s, the Internet began to be widely adopted with massive productivity increases. Which of the options is an appropriate description of the mechanism behind this supply shock?

**a)** The transition from a pre-internet economy to an internet economy was initially costly. Thus, the AS curve probably shifted to the left and unemployment likely increased in the short term.

**(b)** A negative output gap will have resulted in the short term, but was eliminated by shifting the LRAS to the right, which is a likely explanation for the decrease in the inflation rate in the 1990s.

**A positive output gap would have resulted in the short term, but was eliminated by shifting the LRAS to the right, which is a likely explanation for the decrease in the inflation rate in the 1990s.

**d)** The consequent increase in productive capacity led to the rightward shift of the LRAS, which is a likely explanation for the prolonged decline in the unemployment rate in the 1990s.

**e)** None of the above.
"""


# ╔═╡ ed3584d5-ec46-4a40-9bc9-f4ab57601b4d
@bind q21 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f5208a50-1ed6-47d1-9f3c-240cc51fae19
md"""
---
"""

# ╔═╡ f639b432-922a-4e0d-abef-1c23eefd3834
md"""
The two main objectives that the US Federal Reserve (Fed) must achieve are:

**a)** Inflation of 5% and positive interest rates.

**Inflation of 4% and the highest possible level of employment.

**c)** Inflation of 2% and the highest possible level of employment.

**d)** Inflation is not a concern for the Fed.

**e)** None of the above.
"""


# ╔═╡ 65ff5d06-bc16-4c4d-a8ab-08607ad80966
@bind q22 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 62e3db7d-9989-408b-8409-3dd11773caad
md"""
---
"""

# ╔═╡ fcc8673b-1904-4260-91eb-a24e9f899645
md"""
`Yp_shockb = `$(@bind Yp_shockb Slider(-2.0:0.1:2.0, default=0.0, show_value=true))
"""

# ╔═╡ dc32cafe-1398-4786-8143-3f32affe3c59
let
	Ā5 = 5.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.3 ;	r̄5 = 0.5 	# Demand	
	γ5 = 4.0 ; Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 			# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       				# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * (Yᴾ5 + Yp_shockb) + ρ5           				# The AS curve y-axis' intercept
	Y5 = 9.0:0.01:11.0
	Y5_ΔĀ5 = 8.0:0.02:15.0
	r5 = 0.0:0.005:5.0
 
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) 
	πs5 = πs_min5 .+ γ5 .*Y5    
	πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5
	
	trace9_0 = scatter(; x = [10+Yp_shockb,10+Yp_shockb], y = [-7,10], mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	trace9_3 = scatter(; x = [10.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))	
	layout9_5 = Layout(;
					title_text = "Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title="GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [9.2, 10.8],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])
   	p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_5)

	trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")	
	trace4_1 = scatter(; x = [2.0], y = [3.0], text =["1"], 
					textposition = "top center", name ="", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=18, color="black"))
	layout4_3 = Layout(;
					title_text = "MP Curve",
					title_x = 0.5,
					hovermode = "x",
	                xaxis=attr(title="Real interest rate (r)", showgrid=true, zeroline=false),
	                xaxis_range = [0.5, 3.5],
					xaxis_tickvals = [1, 1.5, 2, 2.5, 3, 3.5, 4],
	                yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.0 , 6.0])	
	p4_3 = Plot([trace4_0, trace4_1], layout4_3)
	[p4_3 p9_4]
end


# ╔═╡ 4248014b-ce20-47d4-859a-88e382f968f2
md"""
The figures above represent the initial macroeconomic equilibrium. Suppose there is a permanent shock to supply, such that potential GDP decreases by --0.6 trillion dollars. Using the slider `Yp_shockb` to represent this shock, which of the figures below correspond to the new _long-run_ equilibrium?

**a)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**b)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5.5\%$

**c)** $\pi=10\% \ \  , \ \ Y = 1 \ \ , \ \ r=5\% \ \ , \ \ i = 2\%$

**d)** $\pi=5\% \ \  , \ \ Y = 9.4 \ \ , \ \ r=3\% \ \ , \ \ i = 8\%$

**e)** None of the above.
"""


# ╔═╡ dc479ecd-1183-4372-b734-7d21a3ddd078
@bind q23 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ adb5b6f2-b784-4f6d-925b-adfea599f13c
md"""
---
"""

# ╔═╡ cc6014ea-37c4-43c7-98e9-48949229ffae
md"""
Consider the four fundamental equations of the macroeconomic model studied:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[3mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[3mm]  
\text{MP}: \quad r&=\overline{r}+\lambda \pi \\[3mm]  
\text{Fisher Eq.}: \quad i& =r +\pi
\end{align*}$$

The information about exogenous variables and parameters has already been entered in the cell below:
"""

# ╔═╡ 959d9848-3c0e-46bf-8f9f-76ca95c7c053
begin	
	Ā5 = 5.6 ;	λ5 = 0.5 ;	m5 = 2.0 ;	ϕ5 = 0.3 ;	r̄5 = 0.5 		   	# Demand	
	γ5 = 4.0;	Yᴾ5 = 10.0 ; πᵉ5 = 3.0 ; ρ5 = 0.0 ; 					# Supply		
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       							# The AD curve y-axis' intercept	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5           							# The AS curve y-axis' intercept
end;

# ╔═╡ cd1c3f2b-ac46-4bae-88c2-9af6a10db81b
md"""

o equilíbrio macroeconómico será dado por:

**a)** $\pi=3.5\% \ \  , \ \ Y = 10 \ \ , \ \ r=2\% \ \ , \ \ i = 5\%$

**b)** $\pi=5.5\% \ \  , \ \ Y = 10 \ \ , \ \ r=2.5\% \ \ , \ \ i =0.5\%$

**c)** $\pi=10\% \ \  , \ \ Y = 3 \ \ , \ \ r=2.5\% \ \ , \ \ i = 5\%$

**d)** $\pi=3\% \ \  , \ \ Y = 10 \ \ , \ \ r=2\% \ \ , \ \ i = 5\%$

**e)** Nenhuma das anteriores.
"""


# ╔═╡ 3a82d5b9-dba1-4aac-ad0d-034a17f5d97a


# ╔═╡ adaed021-9d2f-4a94-9a1a-c85951f76f04


# ╔═╡ b5c2be3e-3d0a-48ca-b6b8-8854b9cbd454


# ╔═╡ eeaa812e-8325-4b3d-9793-432ca6745c96
@bind q24 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ e48b3261-3907-4bcc-9080-c3b63b9d5aff
md"""
---
"""

# ╔═╡ 733936c5-ac90-4067-a7f5-aaa5fc0609fe
md"""
The monetary policy rule known as the "Taylor Rule" has the direct objective of helping the central bank to:

**a)** Control GDP.

**b)** Control the unemployment rate.

**c)** Control the inflation rate.

**d)** Prevent bank failures.

**e)** None of the above.
"""


# ╔═╡ 0aa10c63-4f4c-4090-a768-252ed42b63a7
@bind q25 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ f8f4a902-66e4-4874-bfd2-c93a80adef2c
md"""
---
"""

# ╔═╡ c397de26-5d7e-4e78-aead-b505200abd12
md"""
In the ZLB (Zero Lower Bound) context, **secular stagnation** is reflected in which scenario?

**a)** Aggregate demand has suffered a negative shock, getting stuck at a point where aggregate output is lower than what the economy can produce efficiently.

**b)** Aggregate demand has suffered a positive shock, getting stuck at a point where aggregate output is lower than what the economy can produce efficiently.

**c)** Aggregate supply has suffered a negative shock, becoming stuck at a point where aggregate output is lower than the economy can produce efficiently.

**d)** Aggregate supply has suffered a positive shock, becoming stuck at a point where aggregate output is lower than the economy can produce efficiently.

**e)** None of the above.
"""


# ╔═╡ a32c244d-6154-4afd-a710-8919ced949a5
@bind q26 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 83db440d-b6e4-4492-b3ad-dd5a6bb71197
md"""
---
"""

# ╔═╡ 3358f7c3-5c9e-4e66-966a-4290637d1f97
md"""
The Taylor rule for the nominal interest rate depends:

**a)** Negatively on the inflation rate and positively on the target inflation rate.

**b)** Negatively on aggregate output and positively on potential output.

**c)** Positively on the unemployment rate and negatively on the natural unemployment rate.

**d)** Positively on the natural real interest rate.

**e)** None of the above.
"""


# ╔═╡ d4c7c94c-0f49-42f6-9cfd-e4ea72b418c5
@bind q27 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ c4c36a6c-d3cf-4a61-8e22-cf16049e45bf
md"""
---
"""

# ╔═╡ a668d6cd-88e0-4667-9002-2c13fbd8ccaf
html"""<img src="https://vivaldomendes.org/images/Tests/AD_ZLB.png", style="width:500px"/>"""

# ╔═╡ 4a5fd6ae-51b8-46bd-82b7-987412140bec
md"""
The figure above shows the AD curve with the two sections, separated by the "Zero Lower Bound" (ZLB) line. Looking at that figure, why do economists say that in the ZLB area, "the economy is upside down"?

**a)** Because we can't explain anything logically.

**b)** Because GDP and inflation become unrelated.

**c)** Because a 1% reduction in inflation in the normal zone will lead to an increase in GDP; while the same reduction in the ZLB zone will lead to a reduction in GDP.

**d)** Because the central bank stops worrying about inflation.

**e)** None of the above. 
"""


# ╔═╡ 0d650c44-9ef0-49e6-92c0-db4e362fdd16
@bind q28 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 81143434-281c-4761-bb74-1dae94c3e80a
md"""
---
"""

# ╔═╡ e52056bb-02f7-422f-8909-bff74c07fe51
md"""
The figure above shows the AD curve with the two sections, separated by the "Zero Lower Bound" (ZLB) line. Looking at that figure, why do economists say that in the ZLB area, "the economy is upside down"?
What is the situation that, from an economic point of view, is known as the "Zero Lower Bound" (or ZLB)?

**a)** This is when the inflation rate cannot fall below $0\%$.

**b)** This is when the unemployment rate cannot fall below $0\%$.

**c)** This is when the real interest rate cannot fall below $0\%$.

**d)** This is when the nominal interest rate cannot fall below $0\%$.

**e)** None of the above.
"""


# ╔═╡ c78792cf-9a56-472a-a2fe-146102e0cb7d
@bind q29 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 873633fc-9733-487e-a981-338035a4c353
md"""
---
"""

# ╔═╡ fce3a58c-c8e1-4387-b0ae-744828ceacdd
md"""
If the target inflation rate is equal to 2%, current inflation is equal to 2%, and the output gap is equal to zero, then according to the Taylor rule (different from the Taylor Principle), the Fed Funds rate should be:

**a)** 0

**b)** 0,02

**c)** 0,04

**d)** 0,03

**e)** There is not enough information to answer the question.
"""


# ╔═╡ ff8233e6-6b25-46aa-90bd-9da210207fde
@bind q30 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ d3c4b5d3-be6c-4c74-9132-4fb4288aa198
md"""
---
"""

# ╔═╡ 713452a5-156d-498d-8fa8-a1022b9fbb02
md"""
"The ECB considers that the best way to maintain price stability is to aim for inflation of $2\%$ ("target"). This target is _symmetric_, which means that negative and positive deviations of inflation from the target are equally undesirable."" Why did the ECB change its policy to "symmetrical deviations"?

**a)** Because otherwise, the inflation rate in the Eurozone would always tend to be below $2\%$.

**b)** Because the ECB, not knowing quite what to do, decided to do so.

**c)** Because the European Commission decided so.

**d)** Because, otherwise, the inflation rate in the Eurozone would always tend to be above $2\%$.

**e)** None of the above.
"""


# ╔═╡ 729a65fd-3e54-4157-a0f1-09e8414eef64
@bind q31 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 1e4d0fde-9209-41db-bafb-df7247f9d1ad
md"""
---
"""

# ╔═╡ 83a40c45-a611-42d4-bcab-9789a8cc9d0a
md"""
After reaching the ZLB (Zero Lower Bound), the real interest rate will be:

**a)** Negative, if the growth rate of the general price level is negative.

**b)** Positive, if the growth rate of the general price level is positive.

**c)** Nil, if the growth rate of the general price level is negative.

**d)** Nil, if the growth rate of the general price level is positive.

**e)** Negative, if the growth rate of the general price level is positive.
"""


# ╔═╡ 05ca8e1c-e370-41fd-b191-fda90a8427c6
@bind q32 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 0e188a0e-6026-4bce-8323-15e9eccc5001
md"""
---
"""

# ╔═╡ f8318e8b-f811-4215-82c4-5ab5b043388e
md"""
Public debt as a percentage of GDP will become _unsustainable_ over time if:

**a)** The primary deficit as a percentage of GDP is always positive.

**b)** The initial public debt is very high.

**c)** The interest rate paid for issuing public debt is lower than the growth rate of real GDP.

**d)** The interest rate paid on the issue of public debt is higher than the growth rate of real GDP.

**e)** None of the above.
"""


# ╔═╡ 6199aa17-965c-4b74-b2da-8ab086ece24a
@bind q33 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 8e721f9b-09eb-44d5-b18c-618000626a8e
md"""
---
"""

# ╔═╡ b38bcc55-ef7e-4cd4-b32c-09a5dee51399
md"""
Which factor does not influence the level of public debt?

**a)** The primary deficit as a percentage of GDP.

**b)** The growth rate of real GDP.

**c)** The interest rate paid on public debt.

**d)** The amount of reserves in the Central Bank's liabilities.

**e)** The deficit before interest payments.
"""


# ╔═╡ a1e10e97-e8b0-4f19-beb2-725ef28e2c13
@bind q34 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6f4909c4-e7ba-4727-8bb8-a5f73ab2c423
md"""
---
"""

# ╔═╡ 803cce8c-908f-430e-a2bd-8257d97a030d
md"""
Select the incorrect option about one of the two main schools of economic thought.

**a)** Keynesian economists consider that there are significant market failures (market power, public goods, externalities, incomplete markets).

**b)** Classical economists consider that the best scenario in the economy is achieved without government intervention.

**c)** Keynesian economists believe that the government should provide goods and services associated with market failures, in addition to those related to defense, justice, and order.

**d)** Classical economists believe that markets work without failures.

**e)** Keynesian and Classical economists are against any kind of government intervention.
"""


# ╔═╡ 4e7e768b-9dee-4d5c-97bd-db902a7164d7
@bind q35 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 31d352d9-81e8-4e18-96d6-f47468c8d794
md"""
---
"""

# ╔═╡ dc2eb131-e60c-4b28-9f2b-1631654b7801
md"""
Select the incorrect option. The fiscal multiplier is higher if:

**a)** The slope of the AS curve is lower.

**b)** The SA is horizontal.

**c)** The economy is in the ZLB (Zero Lower Bound).

**d)** The slope of the AS curve is vertical.

**e)** The sensitivity of the real interest rate to the inflation rate is close to zero.
"""


# ╔═╡ eccb7a67-f33b-44b7-8ad0-596e800c6f1f
@bind q36 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 6a9777a8-e686-495b-9646-ce1a2e664efa
md"""
---
"""

# ╔═╡ 0f228516-84ec-4850-8502-766b8465396a
md"""
Under normal conditions, the tax multiplier:

**a)** Will be greater if the slope of the AS curve is also greater.

**b)** It will be zero if the AS curve is horizontal.

**c)** Will be higher if the slope of the AS curve is lower.

**d)** It will be quite high if the AS curve is vertical.

**e)** None of the above.
"""


# ╔═╡ 99a7c7bb-8be6-4012-b3b3-d7d1011a43d2
@bind q37 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 0dab35c2-ad9e-4a67-9482-7f3fca5a0a50
md"""
---
"""

# ╔═╡ 02f7d76c-9f1c-48b0-acf4-799473f5c618
md"""
Consider that the growth rate of real GDP is given by $g$, that the real interest rate paid on public debt is given by $r_p$ and that the government's primary balance is negative. Select the correct option.

**a)** Se $g>r_p$ , o nível de dívida pública é insustentável.

**b)** Se $g=r_p$ , o nível de dívida pública é sustentável.

**c)** Se $g<r_p$ , o nível de dívida pública é insustentável.

**d)** $g$ e $r_p$ têm pouco a ver com a sustentabilidade da dívida pública.

**e)** None of the above.
"""

# ╔═╡ c2ecc59f-6219-497f-a835-b19e6b30ac82
@bind q38 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 3b127d77-e211-418d-856b-d64c42ff0e93
md"""
---
"""

# ╔═╡ 76d4698b-a9ef-4ddf-af3f-ceb0ee14cd6f
html"""<img src="https://vivaldomendes.org/images/Tests/multiplier1.png" style="width:600px"/>"""

# ╔═╡ 299264d2-59b3-498d-83e4-4521c2e3c3cf
md"""
The figure above shows three different situations regarding the value of the fiscal multiplier. Which is the situation in which the fiscal multiplier is the highest?

**a)** Case 3.

**b)** Case 0.

**c)** Case 1.

**d)** Case 2,

**e)** None of the above.
"""


# ╔═╡ 5ffa64f3-c53a-4c0d-aaef-9edead28de12
@bind q39 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 55449f00-86f1-4b09-a5e3-a8a96103a09c
md"""
---
"""

# ╔═╡ 13c5238f-9a75-4dc6-a46f-d50b627b14e9
md"""
The three variables that affect the evolution of public debt as a percentage of GDP are:

**a)** Inflation, unemployment, and the real interest rate.

**b)** Inflation, unemployment, and the exchange rate

**c)** The primary deficit as a percentage of GDP, the real interest rate paid on the issue of public debt, and the growth rate of real GDP.

**d)** The primary deficit as a percentage of GDP, the real interest rate paid on the issue of public debt, and the inflation rate.

**e)** None of the above.
"""


# ╔═╡ fcf6d14a-5591-4acf-b48c-2094983c047b
@bind q40 Radio(["a)","b)","c)","d)","e)"])

# ╔═╡ 68b86ced-248d-4cff-bc29-2869eeb2d2d1
md"""
---
"""

# ╔═╡ 2ae50b43-393b-4419-b10f-265f11e17222
md"""
!!! danger "Final instructions"

	You have completed the test.

	The last step is to confirm that you want to **save your answers**, using the **Checkbox after this box**. When you click, a `.csv` file will be generated in the same folder as this Notebook.

	**This is the file you need to send to the teaching team.**

	Before sending, make sure that the date/time in the file makes sense. **Only then should you close the Notebook.**
"""

# ╔═╡ b1e7503f-689d-4b66-aaf0-7e7c6f5e0d67
md"
I confirm that throughout the test, I have always proceeded in accordance with all the **standards of academic ethics and integrity**, that is, without any illicit recourse in the light of ISCTE rules and, in particular, of the Macroeconomics Curricular Unit, so I want to **save my answers** in order to send them to the teaching team for my work to be appropriately evaluated.
$(CheckBox(default=false))
"

# ╔═╡ 53b9e1ed-3f82-4fca-94b1-19c4c9f09120
md"---"

# ╔═╡ 81e65a11-a675-4696-913d-2c0cb8f9f671
md"## Células auxiliares"

# ╔═╡ f0728dc6-97fc-4b41-a6ab-fd73b7fe0a5a
md"### Packages"

# ╔═╡ c855ae34-f784-4abf-b7f0-126f24ed1ba6
md"### CSS code"

# ╔═╡ 4723ffc0-026f-4fee-ae3a-51ab2e080798
html"""
<link href="https://fonts.googleapis.com/css?family=Montserrat:300,300italic,700,700italic" rel="stylesheet">

<style>
	main {
		max-width: 1200px;
		padding: 5%;
        display: block !important;
        margin-left: auto !important;
        margin-right: auto !important;
        user-select: none !important;
         -webkit-user-select: none !important;
         -moz-user-select: none !important;
         -ms-user-select: none !important;
    }
	pluto-output {
		font-family: "Montserrat" !important;
		font-size: 1em;
		line-height: 1.5;
	}
	.plutoui-toc {
		font-family: "Montserrat" !important;
		font-size: 90%;
	}
	.admonition-title {
		font-family: "Montserrat" !important;
	}
	pluto-output h1, h2, h3 {
		font-family: "Montserrat" !important;
		border: none !important;
	}
	pluto-output h1 {
		font-size: 1.8em !important;
		margin-top: 1.5em;
		margin-bottom: 0.5em;
	}
	pluto-output h2 {
		font-size: 1.5em !important;
		margin-top: 1.8em;
		margin-bottom: 1em;
	}
	pluto-output h3 {
		font-size: 1.3em !important;
		margin-top: 1.5em;
		margin-bottom: 1em;
	}
	img:not(picture *) {
		width: 80%;
		display: block;
		margin-left: auto;
		margin-right: auto;
	}
	title {
		font-size: 2.2em;
		display: block;
		font-weight: bold;
		text-align: left;
		margin: 1.5em 0 0em 0;
}
	subtitle {
		font-size: 1.6em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	author {
		display: block;
		text-align: left;
		padding-bottom: 0.8em;
		border-bottom: 3px solid !important;
}
	email {
		display: block;
		text-align: left;
		margin: 0 0 2.5em 0;
}
	semester {
		font-size: 1.3em;
		display: block;
		text-align: left;
		margin: 0 0 1.5em 0;
}
	.admonition-title {
		font-size: 125%;
	}
	ol {
		list-style-type: lower-alpha;
	}
	li::marker {
		font-weight: bold;
	}
	li {
		margin-top: 1em !important;
		margin-bottom: 1em !important;
	}
	.small {
		font-size: 80%;
	}
	.centered-image {
		display: block;
		margin-left: auto;
		margin-right: auto;
		margin-top: 1em;
		margin-bottom: 1em;
		width: 90%;
	}
	details {
		font-size: 80%;
		margin-left: 3em;
	}
	summary {
		font-size: 125%;
		margin-left: -2.2em;
		margin-top: 0.5em;
		margin-bottom: 0.5em;
	}
	input[type="checkbox"] {
		transform: scale(1.5);
	}
	textarea, input[type="text"] {
		font-family: "Montserrat" !important;
		font-size: 0.85em !important;
		line-height: 1.5;
	}
    pluto-cell>button,pluto-input>button,pluto-shoulder {
    display: none !important;
    }
</style>
"""

# ╔═╡ 0be9b5bf-5adb-4ba3-8a04-27db34959e3d
md"### Internal functions"

# ╔═╡ 293b09e0-fd78-4421-ae15-6c8f962cadb1
function tchanã(ans::Union{Nothing,String},correct::String)	
	if typeof(ans) == Nothing
		md"""
		👆 *Please select one answer.*
		"""
	else
		if ans == correct
			md"""
			!!! tip "🎉 Correct answer!"
			"""
		else	
			md"""
			!!! danger "👎 Wrong answer"
				
				Try again. **But study first!!!** 😡
			"""
		end
	end
end;

# ╔═╡ a152b926-f764-469e-9c1b-410c2e89e3cb
tchanã(q01,"a)")

# ╔═╡ 51703aa7-1b20-41f9-a38f-589b239c7c46
tchanã(q02,"d)")

# ╔═╡ ce5330da-fb1e-4203-b96d-9cee9853a7da
tchanã(q03,"d)")

# ╔═╡ d703cdef-0f08-48e6-8792-319995f84fcb
tchanã(q04,"b)")

# ╔═╡ 9702997a-6593-42cd-a4c2-a47ee5cdd75f
tchanã(q05,"d)")

# ╔═╡ 8b474d48-b187-4716-b01e-fb451bcced63
tchanã(q06,"d)")

# ╔═╡ 9d9eaa5d-57d6-41fc-9a2b-2d8ca74f038b
tchanã(q07,"c)")

# ╔═╡ 0db12097-c208-4bb1-a7c5-1f850e3af955
tchanã(q08,"d)")

# ╔═╡ 824332fd-bc74-41ae-97a1-4ce861709ce0
tchanã(q09,"b)")

# ╔═╡ e06ba917-6c4e-4ff3-91be-71265e2cfd5b
tchanã(q10,"e)")

# ╔═╡ 822d2fe6-b794-45f5-902f-da167018e50f
tchanã(q11,"b)")

# ╔═╡ 32448823-c978-4f5d-9f6d-f189e133eb4c
tchanã(q12,"c)")

# ╔═╡ c4a395af-7788-4629-9565-071b9c4d1005
tchanã(q13,"b)")

# ╔═╡ 0ffa6550-e65d-4b2d-9f61-5c55c64fc26c
tchanã(q14,"e)")

# ╔═╡ 18e7a31b-2c16-4eda-8abb-942e359d3f45
tchanã(q15,"d)")

# ╔═╡ 896ae13c-09f8-4607-b3d7-24b0f84150cb
tchanã(q16,"b)")

# ╔═╡ 9cc16770-7506-455d-8351-054b26f058ce
tchanã(q17,"a)")

# ╔═╡ 275c3fe1-0abb-4b6d-8461-1a1101f42475
tchanã(q18,"d)")

# ╔═╡ 9b8698a4-58d5-458d-b179-a1f061bdfd20
tchanã(q19,"b)")

# ╔═╡ 710ac186-87cf-4ef2-aaab-095e80ae6058
tchanã(q20,"d)")

# ╔═╡ 6132fd35-fc23-4230-8c41-10eeb5fadef7
tchanã(q21,"d)")

# ╔═╡ 25a62685-66ba-462e-b90d-b6452d2ac992
tchanã(q22,"c)")

# ╔═╡ 163822b0-c5d4-476c-a710-f6d747e48cfe
tchanã(q23,"d)")

# ╔═╡ cf004b55-4000-44e0-9627-50ccdd188c61
tchanã(q24,"d)")

# ╔═╡ cf187e79-35f9-4399-83b6-a22b36d2b8c9
tchanã(q25,"c)")

# ╔═╡ 665ac3b2-63de-4e78-8cb4-6de9bfa4ead3
tchanã(q26,"a)")

# ╔═╡ c1b20153-9059-42af-a5d0-f268fdbad58b
tchanã(q27,"d)")

# ╔═╡ 082c1a5a-1a16-4d5c-9fc5-54001ab71cd3
tchanã(q28,"c)")

# ╔═╡ caf64d1f-990a-4644-b186-3daac02bd3d1
tchanã(q29,"d)")

# ╔═╡ 4b941c78-e8cc-4b83-af21-186b6a6e6cde
tchanã(q30,"e)")

# ╔═╡ c89fa1f4-4a20-4f44-b632-bcba651f047d
tchanã(q31,"a)")

# ╔═╡ 0c9e8b47-6035-4b4a-8dda-27317844be2c
tchanã(q32,"e)")

# ╔═╡ bd951b0b-3524-46de-9de2-92f1b2b64c09
tchanã(q33,"d)")

# ╔═╡ 7cf9e3a2-6884-4602-91b9-d4d1264f2fa9
tchanã(q34,"d)")

# ╔═╡ 1b12bddc-9603-47b2-a3de-743c010ab5a0
tchanã(q35,"e)")

# ╔═╡ a299e8c4-8915-43c5-a678-06c9a8109692
tchanã(q36,"d)")

# ╔═╡ 82236c3b-60e7-42fb-8bfa-51c83e7bd5a5
tchanã(q37,"c)")

# ╔═╡ e6676b50-e2bb-4586-8083-6ecdbde45f6a
tchanã(q38,"c)")

# ╔═╡ bfed4976-1c8e-4316-be93-386fb347aae6
tchanã(q39,"a)")

# ╔═╡ b4c2ff80-3ee5-4010-a39e-2065b0689b82
tchanã(q40,"c)")

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
CSV = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PeriodicalDates = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoTeachingTools = "661c6b06-c737-4d37-b85c-46df65de6f69"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
StatsBase = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"

[compat]
CSV = "~0.10.10"
DataFrames = "~1.5.0"
HypertextLiteral = "~0.9.4"
NLsolve = "~4.5.1"
PeriodicalDates = "~2.0.0"
PlotlyBase = "~0.8.19"
PlutoTeachingTools = "~0.2.11"
PlutoUI = "~0.7.51"
StatsBase = "~0.34.0"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.9.3"
manifest_format = "2.0"
project_hash = "579384cc5faf1a9c26202f2f8cd4727ad787fa94"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "91bd53c39b9cbfb5ef4b015e8b582d344532bd0a"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.2.0"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "76289dc51920fdc6e0013c872ba9551d54961c24"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "3.6.2"

    [deps.Adapt.extensions]
    AdaptStaticArraysExt = "StaticArrays"

    [deps.Adapt.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra", "Requires", "SparseArrays", "SuiteSparse"]
git-tree-sha1 = "f83ec24f76d4c8f525099b2ac475fc098138ec31"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.4.11"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.CSV]]
deps = ["CodecZlib", "Dates", "FilePathsBase", "InlineStrings", "Mmap", "Parsers", "PooledArrays", "PrecompileTools", "SentinelArrays", "Tables", "Unicode", "WeakRefStrings", "WorkerUtilities"]
git-tree-sha1 = "44dbf560808d49041989b8a96cae4cffbeb7966a"
uuid = "336ed68f-0bac-5ca0-87d4-7b16caf5d00b"
version = "0.10.11"

[[deps.CodeTracking]]
deps = ["InteractiveUtils", "UUIDs"]
git-tree-sha1 = "a1296f0fe01a4c3f9bf0dc2934efbf4416f5db31"
uuid = "da1fd8a2-8d9e-5ec2-8556-3022fb5608a2"
version = "1.3.4"

[[deps.CodecZlib]]
deps = ["TranscodingStreams", "Zlib_jll"]
git-tree-sha1 = "02aa26a4cf76381be7f66e020a3eddeb27b0a092"
uuid = "944b1d66-785c-5afd-91f1-9de20f533193"
version = "0.7.2"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "d9a8f86737b665e15a9641ecbac64deef9ce6724"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.23.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "eb7f0f8307f71fac7c606984ea5fb2817275d6e4"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.4"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "Requires", "Statistics", "TensorCore"]
git-tree-sha1 = "a1f44953f2382ebb937d60dafbe2deea4bd23249"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.10.0"
weakdeps = ["SpecialFunctions"]

    [deps.ColorVectorSpace.extensions]
    SpecialFunctionsExt = "SpecialFunctions"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.CommonSubexpressions]]
deps = ["MacroTools", "Test"]
git-tree-sha1 = "7b8a93dba8af7e3b42fecabf646260105ac373f7"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.0"

[[deps.Compat]]
deps = ["UUIDs"]
git-tree-sha1 = "e460f044ca8b99be31d35fe54fc33a5c33dd8ed7"
uuid = "34da2185-b29b-5c13-b0c7-acf172513d20"
version = "4.9.0"
weakdeps = ["Dates", "LinearAlgebra"]

    [deps.Compat.extensions]
    CompatLinearAlgebraExt = "LinearAlgebra"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.5+0"

[[deps.ConstructionBase]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "fe2838a593b5f776e1597e086dcd47560d94e816"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.3"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Crayons]]
git-tree-sha1 = "249fe38abf76d48563e2f4556bebd215aa317e15"
uuid = "a8cc5b0e-0ffa-5ad4-8c14-923d3ee1735f"
version = "4.1.1"

[[deps.DataAPI]]
git-tree-sha1 = "8da84edb865b0b5b0100c0666a9bc9a0b71c553c"
uuid = "9a962f9c-6df0-11e9-0e5d-c546b8b5ee8a"
version = "1.15.0"

[[deps.DataFrames]]
deps = ["Compat", "DataAPI", "Future", "InlineStrings", "InvertedIndices", "IteratorInterfaceExtensions", "LinearAlgebra", "Markdown", "Missings", "PooledArrays", "PrettyTables", "Printf", "REPL", "Random", "Reexport", "SentinelArrays", "SnoopPrecompile", "SortingAlgorithms", "Statistics", "TableTraits", "Tables", "Unicode"]
git-tree-sha1 = "aa51303df86f8626a962fccb878430cdb0a97eee"
uuid = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
version = "1.5.0"

[[deps.DataStructures]]
deps = ["Compat", "InteractiveUtils", "OrderedCollections"]
git-tree-sha1 = "3dbd312d370723b6bb43ba9d02fc36abade4518d"
uuid = "864edb3b-99cc-5e75-8d2d-829cb0a9cfe8"
version = "0.18.15"

[[deps.DataValueInterfaces]]
git-tree-sha1 = "bfc1187b79289637fa0ef6d4436ebdfe6905cbd6"
uuid = "e2d170a0-9d28-54be-80f0-106bbe20a464"
version = "1.0.0"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "23163d55f885173722d1e4cf0f6110cdbaf7e272"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.15.1"

[[deps.Distances]]
deps = ["LinearAlgebra", "Statistics", "StatsAPI"]
git-tree-sha1 = "b6def76ffad15143924a2199f72a5cd883a2e8a9"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.9"
weakdeps = ["SparseArrays"]

    [deps.Distances.extensions]
    DistancesSparseArraysExt = "SparseArrays"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FilePathsBase]]
deps = ["Compat", "Dates", "Mmap", "Printf", "Test", "UUIDs"]
git-tree-sha1 = "e27c4ebe80e8699540f2d6c805cc12203b614f12"
uuid = "48062228-2e41-5def-b9a4-89aafe57970f"
version = "0.9.20"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Requires", "Setfield", "SparseArrays"]
git-tree-sha1 = "c6e4a1fbe73b31a3dea94b1da449503b8830c306"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.21.1"

    [deps.FiniteDiff.extensions]
    FiniteDiffBandedMatricesExt = "BandedMatrices"
    FiniteDiffBlockBandedMatricesExt = "BlockBandedMatrices"
    FiniteDiffStaticArraysExt = "StaticArrays"

    [deps.FiniteDiff.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.Formatting]]
deps = ["Printf"]
git-tree-sha1 = "8339d61043228fdd3eb658d86c926cb282ae72a8"
uuid = "59287772-0a20-5a39-b81b-1366585eb4c0"
version = "0.4.2"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "cf0fe81336da9fb90944683b8c41984b08793dad"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.36"

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

    [deps.ForwardDiff.weakdeps]
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "c47c5fa4c5308f27ccaac35504858d8914e102f9"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.4"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "d75853a0bdbfb1ac815478bacd89cd27b550ace6"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.3"

[[deps.InlineStrings]]
deps = ["Parsers"]
git-tree-sha1 = "9cc2baf75c6d09f9da536ddf58eb2f29dedaf461"
uuid = "842dd82b-1e85-43dc-bf29-5d0ee9dffc48"
version = "1.4.0"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.InvertedIndices]]
git-tree-sha1 = "0dc7b50b8d436461be01300fd8cd45aa0274b038"
uuid = "41ab1584-1d38-5bbf-9106-f11c6c58b48f"
version = "1.3.0"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.IteratorInterfaceExtensions]]
git-tree-sha1 = "a3f24677c21f5bbe9d2a714f95dcd58337fb2856"
uuid = "82899510-4779-5014-852e-03e436cf321d"
version = "1.0.0"

[[deps.JLLWrappers]]
deps = ["Artifacts", "Preferences"]
git-tree-sha1 = "7e5d6779a1e09a36db2a7b6cff50942a0a7d0fca"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.5.0"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.JuliaInterpreter]]
deps = ["CodeTracking", "InteractiveUtils", "Random", "UUIDs"]
git-tree-sha1 = "81dc6aefcbe7421bd62cb6ca0e700779330acff8"
uuid = "aa1ae85d-cabe-5617-a682-6adf51b2e16a"
version = "0.9.25"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.Latexify]]
deps = ["Formatting", "InteractiveUtils", "LaTeXStrings", "MacroTools", "Markdown", "OrderedCollections", "Printf", "Requires"]
git-tree-sha1 = "f428ae552340899a935973270b8d98e5a31c49fe"
uuid = "23fbe1c1-3f47-55db-b15f-69d7ec21a316"
version = "0.16.1"

    [deps.Latexify.extensions]
    DataFramesExt = "DataFrames"
    SymEngineExt = "SymEngine"

    [deps.Latexify.weakdeps]
    DataFrames = "a93c6f00-e57d-5684-b7b6-d8193f3e46c0"
    SymEngine = "123dc426-2d89-5057-bbad-38513e3affd8"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.3"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "7.84.0+0"

[[deps.LibGit2]]
deps = ["Base64", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.10.2+0"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "7bbea35cec17305fc70a0e5b4641477dc0789d9d"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.2.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "7d6dd4e9212aebaeed356de34ccf262a3cd415aa"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.26"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.LoweredCodeUtils]]
deps = ["JuliaInterpreter"]
git-tree-sha1 = "60168780555f3e663c536500aa790b6368adc02a"
uuid = "6f1432cf-f94c-5a45-995e-cdbf5db27b0b"
version = "2.3.0"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "9ee1618cbf5240e6d4e0371d6f24065083f60c48"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.11"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+0"

[[deps.Missings]]
deps = ["DataAPI"]
git-tree-sha1 = "f66bdc5de519e8f8ae43bdc598782d35a25b1272"
uuid = "e1d29d7a-bbdc-5cf2-9ac0-f12de2c33e28"
version = "1.1.0"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2022.10.11"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "0877504529a3e5c3343c6f8b4c0381e57e4387e4"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.0.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.21+4"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+0"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "13652491f6856acfd2db29360e1bbcd4565d04f1"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.5+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "2e73fe17cac3c62ad1aebe70d44c963c3cfdc3e3"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.2"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "716e24b21538abc91f6205fd1d8363f39b442851"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.7.2"

[[deps.PeriodicalDates]]
deps = ["Dates", "Printf", "RecipesBase"]
git-tree-sha1 = "e616941f8093e50a373e7d51875143213f82eca4"
uuid = "276e7ca9-e0d7-440b-97bc-a6ae82f545b1"
version = "2.0.0"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.9.2"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoHooks]]
deps = ["InteractiveUtils", "Markdown", "UUIDs"]
git-tree-sha1 = "072cdf20c9b0507fdd977d7d246d90030609674b"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0774"
version = "0.0.5"

[[deps.PlutoLinks]]
deps = ["FileWatching", "InteractiveUtils", "Markdown", "PlutoHooks", "Revise", "UUIDs"]
git-tree-sha1 = "8f5fa7056e6dcfb23ac5211de38e6c03f6367794"
uuid = "0ff47ea0-7a50-410d-8455-4348d5de0420"
version = "0.1.6"

[[deps.PlutoTeachingTools]]
deps = ["Downloads", "HypertextLiteral", "LaTeXStrings", "Latexify", "Markdown", "PlutoLinks", "PlutoUI", "Random"]
git-tree-sha1 = "542de5acb35585afcf202a6d3361b430bc1c3fbd"
uuid = "661c6b06-c737-4d37-b85c-46df65de6f69"
version = "0.2.13"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "e47cd150dbe0443c3a3651bc5b9cbd5576ab75b7"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.52"

[[deps.PooledArrays]]
deps = ["DataAPI", "Future"]
git-tree-sha1 = "a6062fe4063cdafe78f4a0a81cfffb89721b30e7"
uuid = "2dfb63ee-cc39-5dd5-95bd-886bf059d720"
version = "1.4.2"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "03b4c25b43cb84cee5c90aa9b5ea0a78fd848d2f"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.2.0"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "7eb1686b4f04b82f96ed7a4ea5890a4f0c7a09f1"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.0"

[[deps.PrettyTables]]
deps = ["Crayons", "LaTeXStrings", "Markdown", "Printf", "Reexport", "StringManipulation", "Tables"]
git-tree-sha1 = "ee094908d720185ddbdc58dbe0c1cbe35453ec7a"
uuid = "08abe8d2-0d0c-5749-adfa-8a2ac140af0d"
version = "2.2.7"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA", "Serialization"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.RecipesBase]]
deps = ["PrecompileTools"]
git-tree-sha1 = "5c3d09cc4f31f5fc6af001c250bf1278733100ff"
uuid = "3cdcf5f2-1ef4-517c-9805-6587b60abb01"
version = "1.3.4"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.Revise]]
deps = ["CodeTracking", "Distributed", "FileWatching", "JuliaInterpreter", "LibGit2", "LoweredCodeUtils", "OrderedCollections", "Pkg", "REPL", "Requires", "UUIDs", "Unicode"]
git-tree-sha1 = "1e597b93700fa4045d7189afa7c004e0584ea548"
uuid = "295af30f-e4ad-537b-8983-00126c2a3abe"
version = "3.5.3"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.SentinelArrays]]
deps = ["Dates", "Random"]
git-tree-sha1 = "04bdff0b09c65ff3e06a05e3eb7b120223da3d39"
uuid = "91c51154-3ec4-41a3-a24f-3f23e20d615c"
version = "1.4.0"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.SnoopPrecompile]]
deps = ["Preferences"]
git-tree-sha1 = "e760a70afdcd461cf01a575947738d359234665c"
uuid = "66db9d55-30c0-4569-8b51-7e840670fc0c"
version = "1.0.3"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SortingAlgorithms]]
deps = ["DataStructures"]
git-tree-sha1 = "c60ec5c62180f27efea3ba2908480f8055e17cee"
uuid = "a2af1166-a08f-5f64-846c-94a0d3cef48c"
version = "1.1.1"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "e2cfc4012a19088254b3950b85c3c1d8882d864d"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.3.1"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArraysCore]]
git-tree-sha1 = "36b3d696ce6366023a0ea192b4cd442268995a0d"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.2"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.9.0"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "45a7769a04a3cf80da1c1c7c60caf932e6f4c9f7"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.6.0"

[[deps.StatsBase]]
deps = ["DataAPI", "DataStructures", "LinearAlgebra", "LogExpFunctions", "Missings", "Printf", "Random", "SortingAlgorithms", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "75ebe04c5bed70b91614d684259b661c9e6274a4"
uuid = "2913bbd2-ae8a-5f71-8c99-4fb6c76f3a91"
version = "0.34.0"

[[deps.StringManipulation]]
git-tree-sha1 = "46da2434b41f41ac3594ee9816ce5541c6096123"
uuid = "892a3eda-7b42-436c-8928-eab12a02cf0e"
version = "0.3.0"

[[deps.SuiteSparse]]
deps = ["Libdl", "LinearAlgebra", "Serialization", "SparseArrays"]
uuid = "4607b0f0-06f3-5cda-b6b1-a6196a1729e9"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "Pkg", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "5.10.1+6"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.TableTraits]]
deps = ["IteratorInterfaceExtensions"]
git-tree-sha1 = "c06b2f539df1c6efa794486abfb6ed2022561a39"
uuid = "3783bdb8-4a98-5b6b-af9a-565f29a5fe9c"
version = "1.0.1"

[[deps.Tables]]
deps = ["DataAPI", "DataValueInterfaces", "IteratorInterfaceExtensions", "LinearAlgebra", "OrderedCollections", "TableTraits", "Test"]
git-tree-sha1 = "1544b926975372da01227b382066ab70e574a3ec"
uuid = "bd369af6-aec1-5ad0-b16a-f7cc5008161c"
version = "1.10.1"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.TranscodingStreams]]
deps = ["Random", "Test"]
git-tree-sha1 = "9a6ae7ed916312b41236fcef7e0af564ef934769"
uuid = "3bb67fe8-82b1-5028-8e26-92a6c54297fa"
version = "0.9.13"

[[deps.Tricks]]
git-tree-sha1 = "aadb748be58b492045b4f56166b5188aa63ce549"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.7"

[[deps.URIs]]
git-tree-sha1 = "b7a5e99f24892b6824a954199a45e9ffcc1c70f0"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.5.0"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.WeakRefStrings]]
deps = ["DataAPI", "InlineStrings", "Parsers"]
git-tree-sha1 = "b1be2855ed9ed8eac54e5caff2afcdb442d52c23"
uuid = "ea10d353-3f73-51f8-a26c-33c1cb351aa5"
version = "1.4.2"

[[deps.WorkerUtilities]]
git-tree-sha1 = "cd1659ba0d57b71a464a29e64dbc67cfe83d54e7"
uuid = "76eceee3-57b5-4d4a-8e66-0e911cebbf60"
version = "1.6.1"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+0"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.8.0+0"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.48.0+0"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+0"
"""

# ╔═╡ Cell order:
# ╟─1f1076c3-5aca-4037-8d45-6a23872ceda4
# ╟─680433b3-98f7-437c-9026-9533c9b4f61e
# ╟─412ff565-a0ac-4014-97f6-e69f36db3fa7
# ╟─4ee58363-aab7-4091-9774-867dd1f1cbf6
# ╟─b9ff1ebd-b7e6-4574-9b19-1b83ea0df6d1
# ╟─4ad6bdf1-3029-43e5-9b0f-cff6525ffe94
# ╟─ca0e61f0-f955-11ed-00af-1f63977dd3de
# ╟─584268fb-7d05-4ec1-aced-acdd66e7d7f4
# ╟─a152b926-f764-469e-9c1b-410c2e89e3cb
# ╟─8d6f36e2-cfd9-4d96-9f42-c862229ca8b7
# ╟─5fd57b29-069d-4a2e-872e-bb9b9bbe1ff0
# ╟─5117e0b7-07f2-440e-9edf-098dc77b128f
# ╟─51703aa7-1b20-41f9-a38f-589b239c7c46
# ╟─cacf356b-2c1f-4b3d-b6e7-3ade4c846b5e
# ╟─7f860aaa-b1bc-4ed7-a9aa-1b07e07cadc3
# ╟─4cf1f4da-e5e3-4fa8-a15c-41bdcc8d5c78
# ╟─ce5330da-fb1e-4203-b96d-9cee9853a7da
# ╟─b938ab03-4579-4c79-89d2-2d2b87d8a57c
# ╟─5265edb5-ec8b-434c-bef2-1b45dbd143b7
# ╟─29889baf-6d1a-45e7-8af4-ea9238715c47
# ╟─617482da-379f-448a-b021-8a2d0a80416e
# ╟─d703cdef-0f08-48e6-8792-319995f84fcb
# ╟─50b2e323-a5a4-4f2f-a82f-678ef2ec0b23
# ╟─8a796898-03c2-4b93-98d8-bb95ae46e45c
# ╟─a8f403a7-6d38-435e-8307-22388809b267
# ╟─9702997a-6593-42cd-a4c2-a47ee5cdd75f
# ╟─6bba8792-7341-469a-a729-4e5297c216a7
# ╟─c0147dfb-3abc-4ef3-9d3d-215cf69deb02
# ╟─5c40e68a-da32-4bd0-af8e-c3141318d0a7
# ╟─a02a491a-ec0f-4ef9-b7c5-e31194f43c8c
# ╟─8b474d48-b187-4716-b01e-fb451bcced63
# ╟─85f2199b-dd49-4cef-b309-2caac31b63a0
# ╟─c0109b03-2c2f-4d93-b74c-b643c986f545
# ╟─6925cd02-56f1-48c7-9b02-c3538e101f4d
# ╟─9d9eaa5d-57d6-41fc-9a2b-2d8ca74f038b
# ╟─c4b23302-22e3-48f7-8d77-72f4b5972162
# ╟─b46aa2bf-8576-44f4-b056-59b5edd8c3dc
# ╟─8a0cf087-7aff-4a17-863e-ee39015ce8a8
# ╟─0db12097-c208-4bb1-a7c5-1f850e3af955
# ╟─7fa1f70b-f880-4606-baf8-f1fe9da4222d
# ╟─9f9e760d-c7d7-420e-8ac2-cf6f26ee837b
# ╟─19e73b89-d4f1-4e82-8ae7-5db98ab7e8c7
# ╟─824332fd-bc74-41ae-97a1-4ce861709ce0
# ╟─e54b0fc3-152b-4d19-a5a8-4ee258c0d6bd
# ╟─70e53de6-c41a-472e-9140-dfcdf28598c9
# ╟─7a93da9a-3380-46f9-944e-83c5ed800c55
# ╟─e06ba917-6c4e-4ff3-91be-71265e2cfd5b
# ╟─e1148fc4-c023-4611-ba8c-526adf723bae
# ╟─649703b9-c02b-4ee0-955a-e79abb826988
# ╟─06d66a09-5a55-4a00-b024-6bf84e2f77ad
# ╟─822d2fe6-b794-45f5-902f-da167018e50f
# ╟─7f3a2da4-2622-472a-a63e-6aa394cabdef
# ╟─ec48a6a7-1565-4075-a933-d029197c6922
# ╟─0183c27d-9e10-4511-95df-067259f0036a
# ╟─d149e58c-7f68-4355-91eb-b4d73466188a
# ╟─32448823-c978-4f5d-9f6d-f189e133eb4c
# ╟─ed418fd6-57ff-46e9-894d-b3acf341b5bd
# ╟─656019a7-57f2-42d8-918f-60f1996af241
# ╟─36490f8f-c8fc-40bf-b2a7-70426e0257ba
# ╟─c4a395af-7788-4629-9565-071b9c4d1005
# ╟─cd0ba554-a065-4fdb-a6f1-ef575c148d04
# ╟─c39dfe8b-97d2-4601-9fa8-0214aca1179a
# ╟─cfe4750f-2af3-42f7-a527-864b56d41733
# ╟─0ffa6550-e65d-4b2d-9f61-5c55c64fc26c
# ╟─56d15a35-50a0-487c-8240-b05f5d45c7b5
# ╟─c6b0c07b-942b-4210-87dd-db00caafed1b
# ╟─9fbf9a0f-759a-4ee8-af34-982779e0e5ee
# ╟─18e7a31b-2c16-4eda-8abb-942e359d3f45
# ╟─e55b164b-0bfe-4f9a-b9af-e3ef80f3b0c8
# ╟─d733cdb8-c84a-4844-bca7-89e4a2ea83bd
# ╟─7981e102-3cf1-4ae1-ae94-c1904d636641
# ╟─896ae13c-09f8-4607-b3d7-24b0f84150cb
# ╟─6697f482-e053-49dd-8b3c-662c27fe2acd
# ╟─b7f5557d-6384-478b-988e-926bdc96e4e7
# ╟─3973a512-fc1a-4dbd-af86-159172e5cd3e
# ╟─9cc16770-7506-455d-8351-054b26f058ce
# ╟─410f0b75-a6b7-4deb-bfd4-64a90d3b5ce2
# ╟─c4be74e5-03c3-4781-a684-765ebc529209
# ╟─1ec91298-655c-4fa3-8c69-6fe281dec2f9
# ╟─183dd55f-b4f2-4645-b427-f2b56365f317
# ╟─c707b9f9-19a9-4eae-8d97-0d2441dd8e61
# ╟─275c3fe1-0abb-4b6d-8461-1a1101f42475
# ╟─93a93d10-e825-4e3f-b513-807496cebc6d
# ╟─479988ae-429b-41d2-8385-4c692fd62ec5
# ╟─3d4ba3e0-45e5-4c33-9f1c-9def0144b1cb
# ╟─0ac221d2-e690-4c16-93d6-770cec789ec6
# ╟─9f263f69-8d7b-4146-ad22-f5e601855eef
# ╟─9b8698a4-58d5-458d-b179-a1f061bdfd20
# ╟─1ef1803f-2961-425f-871a-944c89434779
# ╟─3c693419-e1da-49b8-b6c2-23287a42ecc7
# ╟─78a5cda4-f9f7-4ca7-aa05-ceb9b338c5b8
# ╟─710ac186-87cf-4ef2-aaab-095e80ae6058
# ╟─1862ea80-beef-450c-a24b-9ed120f8f7b7
# ╟─4222da75-5ad0-4a41-bfa3-10749bcc994c
# ╟─ed3584d5-ec46-4a40-9bc9-f4ab57601b4d
# ╟─6132fd35-fc23-4230-8c41-10eeb5fadef7
# ╟─f5208a50-1ed6-47d1-9f3c-240cc51fae19
# ╟─f639b432-922a-4e0d-abef-1c23eefd3834
# ╟─65ff5d06-bc16-4c4d-a8ab-08607ad80966
# ╟─25a62685-66ba-462e-b90d-b6452d2ac992
# ╟─62e3db7d-9989-408b-8409-3dd11773caad
# ╟─fcc8673b-1904-4260-91eb-a24e9f899645
# ╟─dc32cafe-1398-4786-8143-3f32affe3c59
# ╟─4248014b-ce20-47d4-859a-88e382f968f2
# ╟─dc479ecd-1183-4372-b734-7d21a3ddd078
# ╟─163822b0-c5d4-476c-a710-f6d747e48cfe
# ╟─adb5b6f2-b784-4f6d-925b-adfea599f13c
# ╟─cc6014ea-37c4-43c7-98e9-48949229ffae
# ╠═959d9848-3c0e-46bf-8f9f-76ca95c7c053
# ╟─cd1c3f2b-ac46-4bae-88c2-9af6a10db81b
# ╠═3a82d5b9-dba1-4aac-ad0d-034a17f5d97a
# ╠═adaed021-9d2f-4a94-9a1a-c85951f76f04
# ╠═b5c2be3e-3d0a-48ca-b6b8-8854b9cbd454
# ╟─eeaa812e-8325-4b3d-9793-432ca6745c96
# ╟─cf004b55-4000-44e0-9627-50ccdd188c61
# ╟─e48b3261-3907-4bcc-9080-c3b63b9d5aff
# ╟─733936c5-ac90-4067-a7f5-aaa5fc0609fe
# ╟─0aa10c63-4f4c-4090-a768-252ed42b63a7
# ╟─cf187e79-35f9-4399-83b6-a22b36d2b8c9
# ╟─f8f4a902-66e4-4874-bfd2-c93a80adef2c
# ╟─c397de26-5d7e-4e78-aead-b505200abd12
# ╟─a32c244d-6154-4afd-a710-8919ced949a5
# ╟─665ac3b2-63de-4e78-8cb4-6de9bfa4ead3
# ╟─83db440d-b6e4-4492-b3ad-dd5a6bb71197
# ╟─3358f7c3-5c9e-4e66-966a-4290637d1f97
# ╟─d4c7c94c-0f49-42f6-9cfd-e4ea72b418c5
# ╟─c1b20153-9059-42af-a5d0-f268fdbad58b
# ╟─c4c36a6c-d3cf-4a61-8e22-cf16049e45bf
# ╟─a668d6cd-88e0-4667-9002-2c13fbd8ccaf
# ╟─4a5fd6ae-51b8-46bd-82b7-987412140bec
# ╟─0d650c44-9ef0-49e6-92c0-db4e362fdd16
# ╟─082c1a5a-1a16-4d5c-9fc5-54001ab71cd3
# ╟─81143434-281c-4761-bb74-1dae94c3e80a
# ╟─e52056bb-02f7-422f-8909-bff74c07fe51
# ╟─c78792cf-9a56-472a-a2fe-146102e0cb7d
# ╟─caf64d1f-990a-4644-b186-3daac02bd3d1
# ╟─873633fc-9733-487e-a981-338035a4c353
# ╟─fce3a58c-c8e1-4387-b0ae-744828ceacdd
# ╟─ff8233e6-6b25-46aa-90bd-9da210207fde
# ╟─4b941c78-e8cc-4b83-af21-186b6a6e6cde
# ╟─d3c4b5d3-be6c-4c74-9132-4fb4288aa198
# ╟─713452a5-156d-498d-8fa8-a1022b9fbb02
# ╟─729a65fd-3e54-4157-a0f1-09e8414eef64
# ╟─c89fa1f4-4a20-4f44-b632-bcba651f047d
# ╟─1e4d0fde-9209-41db-bafb-df7247f9d1ad
# ╟─83a40c45-a611-42d4-bcab-9789a8cc9d0a
# ╟─05ca8e1c-e370-41fd-b191-fda90a8427c6
# ╟─0c9e8b47-6035-4b4a-8dda-27317844be2c
# ╟─0e188a0e-6026-4bce-8323-15e9eccc5001
# ╟─f8318e8b-f811-4215-82c4-5ab5b043388e
# ╟─6199aa17-965c-4b74-b2da-8ab086ece24a
# ╟─bd951b0b-3524-46de-9de2-92f1b2b64c09
# ╟─8e721f9b-09eb-44d5-b18c-618000626a8e
# ╟─b38bcc55-ef7e-4cd4-b32c-09a5dee51399
# ╟─a1e10e97-e8b0-4f19-beb2-725ef28e2c13
# ╟─7cf9e3a2-6884-4602-91b9-d4d1264f2fa9
# ╟─6f4909c4-e7ba-4727-8bb8-a5f73ab2c423
# ╟─803cce8c-908f-430e-a2bd-8257d97a030d
# ╟─4e7e768b-9dee-4d5c-97bd-db902a7164d7
# ╟─1b12bddc-9603-47b2-a3de-743c010ab5a0
# ╟─31d352d9-81e8-4e18-96d6-f47468c8d794
# ╟─dc2eb131-e60c-4b28-9f2b-1631654b7801
# ╟─eccb7a67-f33b-44b7-8ad0-596e800c6f1f
# ╟─a299e8c4-8915-43c5-a678-06c9a8109692
# ╟─6a9777a8-e686-495b-9646-ce1a2e664efa
# ╟─0f228516-84ec-4850-8502-766b8465396a
# ╟─99a7c7bb-8be6-4012-b3b3-d7d1011a43d2
# ╟─82236c3b-60e7-42fb-8bfa-51c83e7bd5a5
# ╟─0dab35c2-ad9e-4a67-9482-7f3fca5a0a50
# ╟─02f7d76c-9f1c-48b0-acf4-799473f5c618
# ╟─c2ecc59f-6219-497f-a835-b19e6b30ac82
# ╟─e6676b50-e2bb-4586-8083-6ecdbde45f6a
# ╟─3b127d77-e211-418d-856b-d64c42ff0e93
# ╟─76d4698b-a9ef-4ddf-af3f-ceb0ee14cd6f
# ╟─299264d2-59b3-498d-83e4-4521c2e3c3cf
# ╟─5ffa64f3-c53a-4c0d-aaef-9edead28de12
# ╟─bfed4976-1c8e-4316-be93-386fb347aae6
# ╟─55449f00-86f1-4b09-a5e3-a8a96103a09c
# ╟─13c5238f-9a75-4dc6-a46f-d50b627b14e9
# ╟─fcf6d14a-5591-4acf-b48c-2094983c047b
# ╟─b4c2ff80-3ee5-4010-a39e-2065b0689b82
# ╟─68b86ced-248d-4cff-bc29-2869eeb2d2d1
# ╟─2ae50b43-393b-4419-b10f-265f11e17222
# ╟─b1e7503f-689d-4b66-aaf0-7e7c6f5e0d67
# ╟─53b9e1ed-3f82-4fca-94b1-19c4c9f09120
# ╟─81e65a11-a675-4696-913d-2c0cb8f9f671
# ╟─f0728dc6-97fc-4b41-a6ab-fd73b7fe0a5a
# ╟─3eeeedf8-d228-4178-bfc5-710f46649c2a
# ╟─c855ae34-f784-4abf-b7f0-126f24ed1ba6
# ╟─4723ffc0-026f-4fee-ae3a-51ab2e080798
# ╟─0be9b5bf-5adb-4ba3-8a04-27db34959e3d
# ╟─293b09e0-fd78-4421-ae15-6c8f962cadb1
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
